@@ -335,7 +335,9 @@ class Arg(Argument):
                 if key == 'choices':
                     return ', '.join(self.arg.kwargs['choices'])
                 if key == 'default':
-                    default = self.arg.kwargs['default']
+                    default: Union[bytes, int, str] = self.arg.kwargs['default']
+                    if isinstance(default, int):
+                        return default
                     if not isbuffer(default):
                         return str(default)
                     if default.isalnum():
@@ -345,8 +347,9 @@ class Arg(Argument):
                     return self.arg.kwargs.get('metavar', self.arg.destination)
 
         try:
+            help_string: str = self.kwargs['help']
             self.kwargs.update(
-                help=self.kwargs['help'].format_map(formatting()))
+                help=help_string.format_map(formatting()))
         except Exception:
             pass
 
@@ -909,7 +912,7 @@ class Executable(ABCMeta):
 
     @property
     def name(cls) -> str:
-        return cls.__name__.replace('_', '-')
+        return cls.__name__.strip('_').replace('_', '-')
 
 
     logging.addLevelName(logging.CRITICAL, 'failure') # noqa
@@ -1175,7 +1178,9 @@ class Unit(UnitBase, abstract=True):
         return LogLevel(self.logger.getEffectiveLevel())
 
     @log_level.setter
-    def log_level(self, value: LogLevel) -> None:
+    def log_level(self, value: Union[int, LogLevel]) -> None:
+        if not isinstance(value, LogLevel):
+            value = LogLevel.FromVerbosity(value)
         self.logger.setLevel(value)
 
     def log_detach(self) -> None:
@@ -1370,13 +1375,10 @@ class Unit(UnitBase, abstract=True):
         return self
 
     def __str__(self):
-        with MemoryFile() as stdout:
-            return (self | stdout).getbuffer().decode(self.codec)
+        return self | str
 
     def __bytes__(self):
-        with MemoryFile() as stdout:
-            result = bytes((self | stdout).getbuffer())
-        return result
+        return self | bytes
 
     @overload
     def __or__(self, stream: Callable[[ByteString], _T]) -> _T:
@@ -1470,11 +1472,13 @@ class Unit(UnitBase, abstract=True):
             with MemoryFile(stream) as stdout:
                 return (self | stdout).getvalue()
         elif callable(stream):
-            with MemoryFile() as stdout:
+            with MemoryFile(bytearray()) as stdout:
                 self | stdout
-                out = stdout.getbuffer()
+                out: bytearray = stdout.getbuffer()
                 if isinstance(stream, type) and isinstance(out, stream):
                     return out
+                if stream is str:
+                    out = out.decode(self.codec)
                 return stream(out)
 
         if not stream.writable():
@@ -1586,7 +1590,7 @@ class Unit(UnitBase, abstract=True):
         return data
 
     @classmethod
-    def log_fail(cls, *messages, clip=False) -> bool:
+    def log_fail(cls: Union[Executable, Type[Unit]], *messages, clip=False) -> bool:
         """
         Log the message if and only if the current log level is at least `refinery.units.LogLevel.ERROR`.
         """
@@ -1596,7 +1600,7 @@ class Unit(UnitBase, abstract=True):
         return rv
 
     @classmethod
-    def log_warn(cls, *messages, clip=False) -> bool:
+    def log_warn(cls: Union[Executable, Type[Unit]], *messages, clip=False) -> bool:
         """
         Log the message if and only if the current log level is at least `refinery.units.LogLevel.WARN`.
         """
@@ -1606,7 +1610,7 @@ class Unit(UnitBase, abstract=True):
         return rv
 
     @classmethod
-    def log_info(cls, *messages, clip=False) -> bool:
+    def log_info(cls: Union[Executable, Type[Unit]], *messages, clip=False) -> bool:
         """
         Log the message if and only if the current log level is at least `refinery.units.LogLevel.INFO`.
         """
@@ -1616,7 +1620,7 @@ class Unit(UnitBase, abstract=True):
         return rv
 
     @classmethod
-    def log_debug(cls, *messages, clip=False) -> bool:
+    def log_debug(cls: Union[Executable, Type[Unit]], *messages, clip=False) -> bool:
         """
         Log the pmessage if and only if the current log level is at least `refinery.units.LogLevel.DEBUG`.
         """
@@ -1641,6 +1645,7 @@ class Unit(UnitBase, abstract=True):
                 return message
             if isbuffer(message):
                 import codecs
+                message: Union[bytes, bytearray, memoryview]
                 pmsg: str = codecs.decode(message, cls.codec, 'surrogateescape')
                 if not pmsg.isprintable():
                     pmsg = message.hex().upper()
@@ -1757,7 +1762,7 @@ class Unit(UnitBase, abstract=True):
             if args.quiet:
                 unit.log_level = LogLevel.NONE
             else:
-                unit.log_level = LogLevel.FromVerbosity(args.verbose)
+                unit.log_level = args.verbose
 
             return unit
 
